.. Orbit documentation master file, created by
   sphinx-quickstart on Thu Aug 20 13:19:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Orbit's Documentation!
=================================

.. toctree::
   :maxdepth: 1
   :caption: Orbit Core

   installation
   tutorials
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
